[gnome-shell] altTab: Rename List* classes to Switcher*
- From: Florian Müllner <fmuellner src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gnome-shell] altTab: Rename List* classes to Switcher*
- Date: Fri, 17 Jan 2020 14:39:31 +0000 (UTC)
commit 79ccf1a0b5324c54842e0f85068f3c55ea824af9
Author: Jonas Dreßler <verdre v0yd nl>
Date: Sat May 5 15:32:16 2018 +0200
altTab: Rename List* classes to Switcher*
Calling those classes ThumbnailSwitcher and WindowSwitcher makes more
sense since we are using this naming scheme for all classes extending
SwitcherPopup.SwitcherList.
https://gitlab.gnome.org/GNOME/gnome-shell/merge_requests/168
js/ui/altTab.js | 20 ++++++++++----------
1 file changed, 10 insertions(+), 10 deletions(-)
---
diff --git a/js/ui/altTab.js b/js/ui/altTab.js
index 855cd0e988..1e4cbc4534 100644
--- a/js/ui/altTab.js
+++ b/js/ui/altTab.js
@@ -248,20 +248,20 @@ class AppSwitcherPopup extends SwitcherPopup.SwitcherPopup {
this._select(n);
}
- _windowActivated(thumbnailList, n) {
+ _windowActivated(thumbnailSwitcher, n) {
let appIcon = this._items[this._selectedIndex];
Main.activateWindow(appIcon.cachedWindows[n]);
this.fadeAndDestroy();
}
- _windowEntered(thumbnailList, n) {
+ _windowEntered(thumbnailSwitcher, n) {
if (!this.mouseActive)
return;
this._select(this._selectedIndex, n);
}
- _windowRemoved(thumbnailList, n) {
+ _windowRemoved(thumbnailSwitcher, n) {
let appIcon = this._items[this._selectedIndex];
if (!appIcon)
return;
@@ -373,7 +373,7 @@ class AppSwitcherPopup extends SwitcherPopup.SwitcherPopup {
}
_createThumbnails() {
- this._thumbnails = new ThumbnailList(this._items[this._selectedIndex].cachedWindows);
+ this._thumbnails = new ThumbnailSwitcher(this._items[this._selectedIndex].cachedWindows);
this._thumbnails.connect('item-activated', this._windowActivated.bind(this));
this._thumbnails.connect('item-entered', this._windowEntered.bind(this));
this._thumbnails.connect('item-removed', this._windowRemoved.bind(this));
@@ -563,7 +563,7 @@ class WindowSwitcherPopup extends SwitcherPopup.SwitcherPopup {
return;
let mode = this._settings.get_enum('app-icon-mode');
- this._switcherList = new WindowList(windows, mode);
+ this._switcherList = new WindowSwitcher(windows, mode);
this._items = this._switcherList.icons;
}
@@ -811,7 +811,7 @@ class AppSwitcher extends SwitcherPopup.SwitcherList {
}
// We override SwitcherList's highlight() method to also deal with
// the AppSwitcher->ThumbnailList arrows. Apps with only 1 window
// will hide their arrows by default, but show them when their
// thumbnails are visible (ie, when the app icon is supposed to be
// in justOutline mode). Apps with multiple windows will normally
@@ -868,8 +868,8 @@ class AppSwitcher extends SwitcherPopup.SwitcherList {
}
});
-var ThumbnailList = GObject.registerClass(
-class ThumbnailList extends SwitcherPopup.SwitcherList {
+var ThumbnailSwitcher = GObject.registerClass(
+class ThumbnailSwitcher extends SwitcherPopup.SwitcherList {
_init(windows) {
super._init(false);
@@ -1022,8 +1022,8 @@ class WindowIcon extends St.BoxLayout {
}
});
-var WindowList = GObject.registerClass(
-class WindowList extends SwitcherPopup.SwitcherList {
+var WindowSwitcher = GObject.registerClass(
+class WindowSwitcher extends SwitcherPopup.SwitcherList {
_init(windows, mode) {
super._init(true);
[
@@ -811,7 +811,7 @@ class AppSwitcher extends SwitcherPopup.SwitcherList {
}
// We override SwitcherList's highlight() method to also deal with
- // the AppSwitcher->ThumbnailList arrows. Apps with only 1 window
+ // the AppSwitcher->ThumbnailSwitcher arrows. Apps with only 1 window
// will hide their arrows by default, but show them when their
// thumbnails are visible (ie, when the app icon is supposed to be
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]